import pandas as pd
from typing import *
import geopandas as gpd
from pathlib import Path
from types import ModuleType
from datetime import datetime
from pdf2image import convert_from_path
from dataclasses import dataclass, field
from werkzeug.utils import secure_filename
from werkzeug.datastructures import FileStorage
import fnmatch, fnmatch,shlex, os, glob, platform, textwrap, pkgutil,time
import tempfile,shutil,logging,ezodf,fnmatch,pytesseract,pdfplumber,re
import textwrap, sys, types, importlib, importlib.util, inspect,PyPDF2
